# Cocodrilo


[![pypi](https://img.shields.io/pypi/v/cocodrilo.svg)](https://pypi.org/project/cocodrilo/)
[![python](https://img.shields.io/pypi/pyversions/cocodrilo.svg)](https://pypi.org/project/cocodrilo/)
[![Build Status](https://github.com/altaf-ali/cocodrilo/actions/workflows/dev.yml/badge.svg)](https://github.com/altaf-ali/cocodrilo/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/altaf-ali/cocodrilo/branch/main/graphs/badge.svg)](https://codecov.io/github/altaf-ali/cocodrilo)



A large semiaquatic reptile


* Documentation: <https://altaf-ali.github.io/cocodrilo>
* GitHub: <https://github.com/altaf-ali/cocodrilo>
* PyPI: <https://pypi.org/project/cocodrilo/>
* Free software: MIT


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [altaf-ali/cookiecutter-pypackage](https://altaf-ali.github.io/cookiecutter-pypackage) project template.
